Localizer 1.3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Welcome to Localizer’s documentation!

Contents:

- localizer
  - localizer package
    - Subpackages
      - localizer.supported_file_types package
    - Submodules
    - localizer.FileHandler module
      - `FileHandler`
    - localizer.examples module
      - `creating_language_packs()`
      - `easy_mode()`
      - `supported_file_extensions()`
      - `translation_using_APIs()`
      - `using_a_language_pack()`
    - localizer.language_pack module
      - `LanguagePack`
      - `count_spaces()`
    - localizer.print_replace module
      - `input()`
      - `print()`
    - Module contents

# Indices and tables

- Index

- Module Index

- Search Page